==> plantuml-libs-6.0.0.tgz: package/distribution/aws-q3-2021/Resource/NetworkingAndContentDelivery/AmazonCloudFrontStreamingDistribution.md <==
# AmazonCloudFrontStreamingDistribution


```text
aws-q3-2021/Resource/NetworkingAndContentDelivery/AmazonCloudFrontStreamingDistribution
```

```text
include('aws-q3-2021/Resource/NetworkingAndContentDelivery/AmazonCloudFrontStreamingDistribution')
```



| Illustration | AmazonCloudFrontStreamingDistribution | AmazonCloudFrontStreamingDistributionCard | AmazonCloudFrontStreamingDistributionGroup |
| :---: | :---: | :---: | :---: |
| ![illustration for Illustration](../../../aws-q3-2021/Resource/NetworkingAndContentDelivery/AmazonCloudFrontStreamingDistribution.png) | ![illustration for AmazonCloudFrontStreamingDistribution](../../../aws-q3-2021/Resource/NetworkingAndContentDelivery/AmazonCloudFrontStreamingDistribution.Local.png) | ![illustration for AmazonCloudFrontStreamingDistributionCard](../../../aws-q3-2021/Resource/NetworkingAndContentDelivery/AmazonCloudFrontStreamingDistributionCard.Local.png) | ![illustration for AmazonCloudFrontStreamingDistributionGroup](../../../aws-q3-2021/Resource/NetworkingAndContentDelivery/AmazonCloudFrontStreamingDistributionGroup.Local.png) |




## AmazonCloudFrontStreamingDistribution

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://github.com/tmorin/plantuml-libs/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AmazonCloudFrontStreamingDistribution
include('aws-q3-2021/Resource/NetworkingAndContentDelivery/AmazonCloudFrontStreamingDistribution')

' renders the element
AmazonCloudFrontStreamingDistribution('AmazonCloudFrontStreamingDistribution', 'Amazon Cloud Front Streaming Distribution', 'an optional tech label')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AmazonCloudFrontStreamingDistribution
include('aws-q3-2021/Resource/NetworkingAndContentDelivery/AmazonCloudFrontStreamingDistribution')

' renders the element
AmazonCloudFrontStreamingDistribution('AmazonCloudFrontStreamingDistribution', 'Amazon Cloud Front Streaming Distribution', 'an optional tech label')
@enduml
```

## AmazonCloudFrontStreamingDistributionCard

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://github.com/tmorin/plantuml-libs/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AmazonCloudFrontStreamingDistributionCard
include('aws-q3-2021/Resource/NetworkingAndContentDelivery/AmazonCloudFrontStreamingDistribution')

' renders the element
AmazonCloudFrontStreamingDistributionCard('AmazonCloudFrontStreamingDistributionCard', 'Amazon Cloud Front Streaming Distribution Card', 'an optional description')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AmazonCloudFrontStreamingDistributionCard
include('aws-q3-2021/Resource/NetworkingAndContentDelivery/AmazonCloudFrontStreamingDistribution')

' renders the element
AmazonCloudFrontStreamingDistributionCard('AmazonCloudFrontStreamingDistributionCard', 'Amazon Cloud Front Streaming Distribution Card', 'an optional description')
@enduml
```

## AmazonCloudFrontStreamingDistributionGroup

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://github.com/tmorin/plantuml-libs/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AmazonCloudFrontStreamingDistributionGroup
include('aws-q3-2021/Resource/NetworkingAndContentDelivery/AmazonCloudFrontStreamingDistribution')

' renders the element
AmazonCloudFrontStreamingDistributionGroup('AmazonCloudFrontStreamingDistributionGroup', 'Amazon Cloud Front Streaming Distribution Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AmazonCloudFrontStreamingDistributionGroup
include('aws-q3-2021/Resource/NetworkingAndContentDelivery/AmazonCloudFrontStreamingDistribution')

' renders the element
AmazonCloudFrontStreamingDistributionGroup('AmazonCloudFrontStreamingDistributionGroup', 'Amazon Cloud Front Streaming Distribution Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

==> plantuml-libs-6.3.0.tgz: package/distribution/aws-q3-2021/Resource/NetworkingAndContentDelivery/AmazonCloudFrontStreamingDistribution.md <==
# AmazonCloudFrontStreamingDistribution


```text
aws-q3-2021/Resource/NetworkingAndContentDelivery/AmazonCloudFrontStreamingDistribution
```

```text
include('aws-q3-2021/Resource/NetworkingAndContentDelivery/AmazonCloudFrontStreamingDistribution')
```



| Illustration | AmazonCloudFrontStreamingDistribution | AmazonCloudFrontStreamingDistributionCard | AmazonCloudFrontStreamingDistributionGroup |
| :---: | :---: | :---: | :---: |
| ![illustration for Illustration](../../../aws-q3-2021/Resource/NetworkingAndContentDelivery/AmazonCloudFrontStreamingDistribution.png) | ![illustration for AmazonCloudFrontStreamingDistribution](../../../aws-q3-2021/Resource/NetworkingAndContentDelivery/AmazonCloudFrontStreamingDistribution.Local.png) | ![illustration for AmazonCloudFrontStreamingDistributionCard](../../../aws-q3-2021/Resource/NetworkingAndContentDelivery/AmazonCloudFrontStreamingDistributionCard.Local.png) | ![illustration for AmazonCloudFrontStreamingDistributionGroup](../../../aws-q3-2021/Resource/NetworkingAndContentDelivery/AmazonCloudFrontStreamingDistributionGroup.Local.png) |




## AmazonCloudFrontStreamingDistribution

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AmazonCloudFrontStreamingDistribution
include('aws-q3-2021/Resource/NetworkingAndContentDelivery/AmazonCloudFrontStreamingDistribution')

' renders the element
AmazonCloudFrontStreamingDistribution('AmazonCloudFrontStreamingDistribution', 'Amazon Cloud Front Streaming Distribution', 'an optional tech label')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AmazonCloudFrontStreamingDistribution
include('aws-q3-2021/Resource/NetworkingAndContentDelivery/AmazonCloudFrontStreamingDistribution')

' renders the element
AmazonCloudFrontStreamingDistribution('AmazonCloudFrontStreamingDistribution', 'Amazon Cloud Front Streaming Distribution', 'an optional tech label')
@enduml
```

## AmazonCloudFrontStreamingDistributionCard

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AmazonCloudFrontStreamingDistributionCard
include('aws-q3-2021/Resource/NetworkingAndContentDelivery/AmazonCloudFrontStreamingDistribution')

' renders the element
AmazonCloudFrontStreamingDistributionCard('AmazonCloudFrontStreamingDistributionCard', 'Amazon Cloud Front Streaming Distribution Card', 'an optional description')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AmazonCloudFrontStreamingDistributionCard
include('aws-q3-2021/Resource/NetworkingAndContentDelivery/AmazonCloudFrontStreamingDistribution')

' renders the element
AmazonCloudFrontStreamingDistributionCard('AmazonCloudFrontStreamingDistributionCard', 'Amazon Cloud Front Streaming Distribution Card', 'an optional description')
@enduml
```

## AmazonCloudFrontStreamingDistributionGroup

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AmazonCloudFrontStreamingDistributionGroup
include('aws-q3-2021/Resource/NetworkingAndContentDelivery/AmazonCloudFrontStreamingDistribution')

' renders the element
AmazonCloudFrontStreamingDistributionGroup('AmazonCloudFrontStreamingDistributionGroup', 'Amazon Cloud Front Streaming Distribution Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AmazonCloudFrontStreamingDistributionGroup
include('aws-q3-2021/Resource/NetworkingAndContentDelivery/AmazonCloudFrontStreamingDistribution')

' renders the element
AmazonCloudFrontStreamingDistributionGroup('AmazonCloudFrontStreamingDistributionGroup', 'Amazon Cloud Front Streaming Distribution Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```
